
module top(

   //////// CLOCK //////////
   input config_clk,  // 50MHz clock 
   input Mem0_RefClk, // 50MHz clock
 //  input Mem1_RefClk, // 50MHz clock
   input kernel_pll_refclk_clk, // 50MHz clock


   //////// Power //////////
//   output USER_1P35V_EN,
//   output MARGIN_EN,
//   output MARGIN_HIGH,

   //////// PCIe //////////
   input        pcie_refclk,
   input        perstl0_n,  // Reset to embedded PCIe
   input        hip_serial_rx_in0,
   input        hip_serial_rx_in1,
   input        hip_serial_rx_in2,
   input        hip_serial_rx_in3,
   output       hip_serial_tx_out0,
   output       hip_serial_tx_out1,
   output       hip_serial_tx_out2,
   output       hip_serial_tx_out3,

   //////// DDR3 //////////
   output        Mem0_Reset_n,
   output [15:0] Mem0_Addr,
   output [2:0]  Mem0_Bank,
   output        Mem0_Cas_n,
   output        Mem0_Cke,
   output        Mem0_Ck,
   output        Mem0_Ck_n,
   output        Mem0_Cs_n,
   output [7:0]  Mem0_Dm,
   inout [63:0]  Mem0_Dq,
   inout  [7:0]  Mem0_Dqs,
   inout  [7:0]  Mem0_Dqs_n,
   output        Mem0_Odt,
   output        Mem0_Ras_n,
   output        Mem0_We_n,
   input         Mem0_Rzq,



   //////// LED //////////
   output [7:0] leds
);

//=======================================================
//  PARAMETER declarations
//=======================================================

//=======================================================
//  REG/WIRE declarations
//=======================================================
wire resetn;
wire npor;


//=======================================================
//  Board-specific 
//=======================================================

//assign USER_1P35V_EN = 1'b1;  // Force 1.35V supply on
//assign MARGIN_EN = 1'b1;
//assign MARGIN_HIGH = 1'b1;

//=======================================================
//  Reset logic 
//=======================================================
assign resetn = 1'b1;

//=======================================================
//  System instantiation
//=======================================================

system system_inst 
(
   // Global signals
   .global_reset_reset_n( resetn ),  // No hard reset !!!
   .config_clk_clk( config_clk ),
   .ddr3a_pll_ref_clk( Mem0_RefClk ),

   // PCIe pins
   .pcie_npor_pin_perst(perstl0_n),
   .pcie_npor_npor(1'b1),
   .pcie_npor_out_reset_n(npor),
   .pcie_refclk_clk( pcie_refclk ),
   .pcie_rx_in0( hip_serial_rx_in0 ),
   .pcie_rx_in1( hip_serial_rx_in1 ),
   .pcie_rx_in2( hip_serial_rx_in2 ),
   .pcie_rx_in3( hip_serial_rx_in3 ),
   .pcie_tx_out0( hip_serial_tx_out0 ),
   .pcie_tx_out1( hip_serial_tx_out1 ),
   .pcie_tx_out2( hip_serial_tx_out2 ),
   .pcie_tx_out3( hip_serial_tx_out3 ),

   // DDR3 pins
   .ddr3a_mem_reset_n( Mem0_Reset_n ),
   .ddr3a_mem_a( Mem0_Addr ),
   .ddr3a_mem_ba( Mem0_Bank ),
   .ddr3a_mem_cas_n( Mem0_Cas_n ),
   .ddr3a_mem_ck( Mem0_Ck ),
   .ddr3a_mem_ck_n( Mem0_Ck_n ),
   .ddr3a_mem_cke( Mem0_Cke ),
   .ddr3a_mem_cs_n( Mem0_Cs_n ),
   .ddr3a_mem_dm( Mem0_Dm ),
   .ddr3a_mem_dq( Mem0_Dq ),
   .ddr3a_mem_dqs_n( Mem0_Dqs_n ),
   .ddr3a_mem_dqs( Mem0_Dqs ),
   .ddr3a_mem_oct_rzqin( Mem0_Rzq ),
   .ddr3a_mem_odt( Mem0_Odt ),
   .ddr3a_mem_ras_n( Mem0_Ras_n ),
   .ddr3a_mem_we_n( Mem0_We_n ),

   .reconfig_to_xcvr_reconfig_to_xcvr({5{24'h0, 2'b11, 44'h0}}),
   .reconfig_from_xcvr_reconfig_from_xcvr(),
   .kernel_pll_refclk_clk( kernel_pll_refclk_clk )
);

assign leds[3:0] = 4'b1100;

endmodule
